## khPaper.R
## 31 august 2013
## generate stats and plots for Labphon paper

require(Hotelling)
require(plyr)

setwd('/Users/jkirby/Dropbox/Documents/Khmer/simulation/labphon')
source('khSims.R')
source('khUtils.R')
source('khPlots.R')

## PP post
pp_est <- read.csv('post-est.txt', header=T)
pp <- data.frame()
for (i in 1:100) {
    agent <- init(pp_est, 33)
    agent$id <- rep(i, 33)
    agent$t <- rep(0, 33)
    pp <- rbind(pp, agent)
}
pp[9000,]$r<-40 ## to force reasonable x axis

quartz(,9,2.75)
densityPlotNoR(pp, 0)


## KG plots
kg_est <- read.csv('kg-est.txt', header=T)                                                                                                             
kg <- data.frame() 
for (i in 1:100) {
    agent <- init(kg_est, 33)
    agent$id <- rep(i, 33)
    agent$t <- rep(0, 33)
    kg <- rbind(kg, agent)
}
kg[9000,]$r<-40

quartz(,8,2.75)
densityPlotNoR(kg, 0) 


## stable evolution
run50stable <- khmerSim(nGens=50, nLearners=100, nExamples=1000, rBias=0)
#load('/Users/jkirby/Desktop/khRuns/run50stable/Run-50-333-100-0-comp-2013-08-28-122706-863.xz')
#run50stable <- resultList

## initial PP plots
quartz(,11,2.75)
densityPlot(resultList$densityDf, 0)
grid.text(0, x=0.94, y=0.825, gp=gpar(fontsize=16))

## evolution plots
quartz(,11,2.75)
meanSdPlot(resultList$summaryStatsDf)
#meanSdPlot(droplevels(subset(resultList$summaryStatsDf, t<=20)))
quartz(,5,5)
meanSdPlotBox(resultList$summaryStatsDf)


## non-compensators
run50non <- khmerSim(nGens=50, nLearners=100, nExamples=1000, rBias=0.2, cGroup="non")
#load('/Users/jkirby/Desktop/khRuns/clean/run50non/Run-50-333-100-0.2-non-2013-09-02-180528-851.xz')
#run50non <- resultList
quartz(,11,2.75)
meanSdPlot(run50non$summaryStatsDf)
quartz(,5,5)
meanSdPlotBox(run50non$summaryStatsDf)

## density plot without /r/
quartz(,9,2.75)
densityPlotNoR(run50non$densityDf, 50)
grid.text(50, x=0.925, y=0.825, gp=gpar(fontsize=16))

## Hotelling T^2 test
sf=subset(run50non$densityDf, t==49 | t==50)
fit=hotelling.test(.~t, data=subset(sf,class=='k')[,c(1:5)])
## etc

## summary tables
df <- subset(run50non$densityDf, t==0 | t==5 | t==10 | t==20 | t==50)
dmelt <- melt(df[,c(1:6)], id.vars=c('t', 'class'))
dsum <- ddply(dmelt, .(t, class,variable), summarize, mean=round(mean(value),2), sd=round(sd(value),2))
dmu <- dsum[,c(1:4)]
dsd <- dsum[,c(1:3,5)]
names(dmu)<-c('t','class','variable','value')
names(dsd)<-c('t','class','variable','value')
dmu$stat<-rep('mean')
dsd$stat<-rep('sd')
dstat<-rbind(dmu,dsd)
acast(dstat, t~class~stat~variable)

## compensators
run50comp <- khmerSim(nGens=50, nLearners=100, nExamples=1000, rBias=0.2, cGroup="comp")
#load('/Users/jkirby/Desktop/khRuns/clean/run50comp/Run-50-333-100-0.2-comp-2013-08-27-002023-567.xz')
#run50comp <- resultList
quartz(,11,2.75)
meanSdPlot(run50comp$summaryStatsDf)
quartz(,5,5)
meanSdPlotBox(run50comp$summaryStatsDf)

quartz(,9,2.75)
densityPlotNoR(run50comp$densityDf, 50)
grid.text(50, x=0.925, y=0.825, gp=gpar(fontsize=16))

## summary tables
df <- subset(run50comp$densityDf, t==0 | t==5 | t==10 | t==20 | t==50)
dmelt <- melt(df[,c(1:6)], id.vars=c('t', 'class'))
dsum <- ddply(dmelt, .(t, class,variable), summarize, mean=round(mean(value),2), sd=round(sd(value),2))
dmu <- dsum[,c(1:4)]
dsd <- dsum[,c(1:3,5)]
names(dmu)<-c('t','class','variable','value')
names(dsd)<-c('t','class','variable','value')
dmu$stat<-rep('mean')
dsd$stat<-rep('sd')
dstat<-rbind(dmu,dsd)
acast(dstat, t~class~stat~variable)

## error rates
eg_stable <- run50stable$errorDf
eg_stable$series <- rep('Series I')
eg_non <- run50error$errorDf
eg_non$series <- rep('Series II')
eg_comp <- run50comp$errorDf
eg_comp$series <- rep('Series III')
eg <- rbind(eg_stable, eg_non, eg_comp)
quartz(,7.85,2.75)
errorPlot(eg) 
grid.text('Generation 9: 0.24', x=0.535, y=0.765, gp=gpar(fontsize=9))
grid.text('Generation 50: 0.002', x=0.575, y=0.3, gp=gpar(fontsize=9))
grid.text('Generation 9: 0.26', x=0.855, y=0.765, gp=gpar(fontsize=9))
grid.text('Generation 50: 0.003', x=0.89, y=0.3, gp=gpar(fontsize=9))
