## khPlots.R
## 27 august 2013

require(ggplot2)

theme_set(theme_bw())

myPalette <- c("#E41A1C", "#377EB8", "#4DAF4A", "#984EA3")

densityPlot <- function(joint, iter) {
    mj <- melt(droplevels(subset(joint,t==iter)), measure.vars=c('vot','f0','h1h2','r'))
    mj$variable<-revalue(mj$variable, c('vot'='VOT (ms)', 'f0'='f0 (Hz)', 'h1h2'='H1-H2 (dB)', 'r'='duration of /r/ (ms)')) 
    ggplot(mj,aes(value,colour=class,linetype=class)) + facet_wrap(~variable,scales="free",nrow=1) + geom_density(size=1,adjust=2) + theme(axis.text.x = element_text(size = 11), axis.text.y = element_text(size = 11), axis.title.x = element_text(vjust = -0.15, hjust=0.5, size = 11), axis.title.y = element_text(angle = 90, vjust = 0.125, size = 11), legend.text=element_text(size=11), legend.title=element_text(size=11), panel.margin = unit(1, "lines")) + scale_colour_grey(start=0,end=0.5) 
}

densityPlotNoR <- function(joint, iter) {
    mj <- melt(droplevels(subset(joint,t==iter)), measure.vars=c('vot','f0','h1h2'))
    mj$variable<-revalue(mj$variable, c('vot'='VOT (ms)', 'f0'='f0 (Hz)', 'h1h2'='H1-H2 (dB)')) 
    ggplot(mj,aes(value,colour=class,linetype=class)) + facet_wrap(~variable,scales="free",nrow=1) + geom_density(size=1, adjust=2) + theme(axis.text.x = element_text(size = 11), axis.text.y = element_text(size = 11), axis.title.x = element_text(vjust = -0.15, hjust=0.5, size = 11), axis.title.y = element_text(angle = 90, vjust = 0.125, size = 11), legend.text=element_text(size=11), legend.title=element_text(size=11), panel.margin = unit(1, "lines")) + scale_colour_grey(start=0,end=0.5) 
}

errorPlot <- function(eg) {
        ggplot(eg, aes(t,error)) + geom_line(size=1, show_guide=TRUE) + xlab('generation') + ylab('error rate') + theme(axis.text.x = element_text(size = 11), axis.text.y = element_text(size = 11), axis.title.x = element_text(vjust = -0.15, hjust=0.5, size = 11), axis.title.y = element_text(angle = 90, vjust = 0.125, size = 11), legend.text=element_text(size=11), legend.title=element_text(size=11), panel.margin = unit(2.1, "lines")) + facet_wrap(~series, nrow=1)

}

meanSdPlot <- function(resultsDf){
    g <- ggplot(aes(x = t, y=mean, ymin=mean-1.96*sd, ymax=mean+1.96*sd, group=class), data=resultsDf) +
         geom_ribbon(alpha=0.2) + geom_line(aes(linetype=class), size=0.75) + xlab("generation") + ylab("mean +/- 2 SD") + 
         facet_wrap(~cue,scales='free_y',nrow=1) + theme(axis.title.x = element_text(vjust = -0.15, hjust=0.5, size = 12), 
         axis.title.y = element_text(angle = 90, vjust = 0.125, size = 12), panel.margin = unit(1, "lines"))
  return(g)
}

meanSdPlotBox <- function(resultsDf){
    g <- ggplot(aes(x = t, y=mean, ymin=mean-1.96*sd, ymax=mean+1.96*sd, group=class), data=resultsDf) +
         geom_ribbon(alpha=0.2) + geom_line(aes(linetype=class), size=0.75) + xlab("generation") + ylab("mean +/- 2 SD") + 
         facet_wrap(~cue,scales='free_y',nrow=2) + theme(axis.title.x = element_text(vjust = -0.15, hjust=0.5, size = 12), 
         axis.title.y = element_text(angle = 90, vjust = 0.125, size = 12), panel.margin = unit(1, "lines"), legend.position="top", legend.direction="horizontal")
  return(g)
}

