## khUtils.R
## 27 august 2013

require(MASS)
require(mvtnorm)
require(msm) ## for rtnorm()


## helper functions
err <- function(x) return(1-(x[1,1]+x[2,2]+x[3,3])/sum(x))
sample.df <- function(df, n) df[sample(nrow(df), n), , drop = FALSE]


## produce initial distribution
init <- function(estimates, memleng) {
	kuu.vot = rnorm(memleng, subset(estimates, class=='k' & var=='vot')$mean, subset(estimates, class=='k' & var=='vot')$sd)
	kuu.f0 = rnorm(memleng, subset(estimates, class=='k' & var=='f0')$mean, subset(estimates, class=='k' & var=='f0')$sd)
	kuu.h1h2 = rnorm(memleng, subset(estimates, class=='k' & var=='h1h2')$mean, subset(estimates, class=='k' & var=='h1h2')$sd)
	kuu.r = rep(0, memleng)

	kuu = data.frame(vot = kuu.vot, f0 = kuu.f0, h1h2 = kuu.h1h2, r = kuu.r, class = 'k')

	khuu.vot = rnorm(memleng, subset(estimates, class=='kh' & var=='vot')$mean, subset(estimates, class=='kh' & var=='vot')$sd)
	khuu.f0 = rnorm(memleng, subset(estimates, class=='kh' & var=='f0')$mean, subset(estimates, class=='kh' & var=='f0')$sd)
	khuu.h1h2 = rnorm(memleng, subset(estimates, class=='kh' & var=='h1h2')$mean, subset(estimates, class=='kh' & var=='h1h2')$sd)
	khuu.r = rep(0, memleng)

	khuu = data.frame(vot = khuu.vot, f0 = khuu.f0, h1h2 = khuu.h1h2, r = khuu.r, class = 'kh')

	kruu.vot = rnorm(memleng, subset(estimates, class=='kr' & var=='vot')$mean, subset(estimates, class=='kr' & var=='vot')$sd)
	kruu.f0 = rnorm(memleng, subset(estimates, class=='kr' & var=='f0')$mean, subset(estimates, class=='kr' & var=='f0')$sd)
	kruu.h1h2 = rnorm(memleng, subset(estimates, class=='kr' & var=='h1h2')$mean, subset(estimates, class=='kr' & var=='h1h2')$sd)
    if (subset(estimates, class=='kr' & var=='r')$sd != 0) {
	    kruu.r = rtnorm(memleng, subset(estimates, class=='kr' & var=='r')$mean, subset(estimates, class=='kr' & var=='r')$sd, lower=0)
    } else { kruu.r <- rep(0, memleng) } 
	kruu = data.frame(vot = kruu.vot, f0 = kruu.f0, h1h2 = kruu.h1h2, r = kruu.r, class = 'kr')
	
	joint <- rbind(kuu, khuu, kruu)
	return(joint)
}


## sample from multivariate Gaussians
sampleMVT <- function(joint, c1, c2, c3, noise) {                                                                                                    
                                                                                                                                                           
    k<-droplevels(subset(joint, class=='k'))                                                                                                               
    kh<-droplevels(subset(joint, class=='kh'))                                                                                                             
    kr<-droplevels(subset(joint, class=='kr' & r > 0))                                                                                                     
                                                                                                                                                           
    kuuhat = list(); khuuhat = list(); kruuhat = list()                                                                                                    
                                                                                                                                                           
    kuuhat$muhat = c(mean(k[,1]), mean(k[,2]), mean(k[,3]), mean(k[,4]))                                                                                   
    kuuhat$sigmahat = cov(k[,1:4])                                                                                                                         
    khuuhat$muhat = c(mean(kh[,1]), mean(kh[,2]), mean(kh[,3]), mean(kh[,4]))                                                                              
    khuuhat$sigmahat = cov(kh[,1:4])                                                                                                                       
    kruuhat$muhat = c(mean(kr[,1]), mean(kr[,2]), mean(kr[,3]), mean(kr[,4]))                                                                              
    kruuhat$sigmahat = cov(kr[,1:4])                                                                                                                       
                                                                                                                                                           
    kuu = as.data.frame(rmvnorm(c1, kuuhat$muhat, kuuhat$sigmahat))                                                                                        
    if (noise==TRUE) { kuu <- kuu + rmvnorm(c1, rep(0,4)) }
    kuu <- cbind(kuu, class=rep('k', c1))                                                                                                                  
    names(kuu)<-c('vot', 'f0', 'h1h2', 'r', 'class')                                                                                                       
    kuu$r <- 0                                                                                                                                             
                                                                                                                                                           
    khuu = as.data.frame(rmvnorm(c2, khuuhat$muhat, khuuhat$sigmahat))                                                                                     
    if (noise==TRUE) { khuu <- khuu + rmvnorm(c2, rep(0,4)) }
    khuu <- cbind(khuu, class=rep('kh', c2))                                                                                                               
    names(khuu)<-c('vot', 'f0', 'h1h2', 'r', 'class')                                                                                                      
    khuu$r <- 0                                                                                                                                            
                                                                                                                                                           
    kruu = as.data.frame(rmvnorm(c3, kruuhat$muhat, kruuhat$sigmahat))                                                                                     
    if (noise==TRUE) { kruu <- kruu + rmvnorm(c3, rep(0,4)) }
    kruu <- cbind(kruu, class=rep('kr', c3))                                                                                                               
    names(kruu)<-c('vot', 'f0', 'h1h2', 'r', 'class')                                                                                                      
    kruu$r = rtnorm(c3, mean(kr$r), sd(kr$r), lower=0, upper=max(kr$r))                                                                                    
    if (noise==TRUE) { kruu$r <- kruu$r + rnorm(c3) }
    
    joint <- rbind(kuu, khuu, kruu)                                                                                                                        
    return(joint)                                                                                                                                          
}                    

